@@ -23,12 +23,18 @@ complete -o default -F _pip_completion pip""",
         "fish",
         """\
 function __fish_complete_pip
-    set -lx COMP_WORDS (commandline -o) ""
-    set -lx COMP_CWORD ( \\
-        math (contains -i -- (commandline -t) $COMP_WORDS)-1 \\
-    )
+    set -lx COMP_WORDS \\
+        (commandline --current-process --tokenize --cut-at-cursor) \\
+        (commandline --current-token --cut-at-cursor)
+    set -lx COMP_CWORD (math (count $COMP_WORDS) - 1)
     set -lx PIP_AUTO_COMPLETE 1
-    string split \\  -- (eval $COMP_WORDS[1])
+    set -l completions
+    if string match -q '2.*' $version
+        set completions (eval $COMP_WORDS[1])
+    else
+        set completions ($COMP_WORDS[1])
+    end
+    string split \\  -- $completions
 end
 complete -fa "(__fish_complete_pip)" -c pip""",
     ),
