@@ -1,7 +1,7 @@
 import json
 import textwrap
 from pathlib import Path
-from typing import Any, Dict
+from typing import Any, Dict, Tuple
 
 import pytest
 from packaging.utils import canonicalize_name
@@ -39,7 +39,7 @@ def test_install_report_basic(
     assert url.endswith("/packages/simplewheel-2.0-1-py2.py3-none-any.whl")
     assert (
         simplewheel_report["download_info"]["archive_info"]["hash"]
-        == "sha256=191d6520d0570b13580bf7642c97ddfbb46dd04da5dd2cf7bef9f32391dfe716"
+        == "sha256=71e1ca6b16ae3382a698c284013f66504f2581099b2ce4801f60e9536236ceee"
     )
 
 
@@ -64,14 +64,79 @@ def test_install_report_dep(
     assert _install_dict(report)["simple"]["requested"] is False
 
 
+def test_yanked_version(
+    script: PipTestEnvironment, data: TestData, tmp_path: Path
+) -> None:
+    """
+    Test is_yanked is True when explicitly requesting a yanked package.
+    Yanked files are always ignored, unless they are the only file that
+    matches a version specifier that "pins" to an exact version (PEP 592).
+    """
+    report_path = tmp_path / "report.json"
+    script.pip(
+        "install",
+        "simple==3.0",
+        "--index-url",
+        data.index_url("yanked"),
+        "--dry-run",
+        "--report",
+        str(report_path),
+        allow_stderr_warning=True,
+    )
+    report = json.loads(report_path.read_text())
+    simple_report = _install_dict(report)["simple"]
+    assert simple_report["requested"] is True
+    assert simple_report["is_direct"] is False
+    assert simple_report["is_yanked"] is True
+    assert simple_report["metadata"]["version"] == "3.0"
+
+
+def test_skipped_yanked_version(
+    script: PipTestEnvironment, data: TestData, tmp_path: Path
+) -> None:
+    """
+    Test is_yanked is False when not explicitly requesting a yanked package.
+    Yanked files are always ignored, unless they are the only file that
+    matches a version specifier that "pins" to an exact version (PEP 592).
+    """
+    report_path = tmp_path / "report.json"
+    script.pip(
+        "install",
+        "simple",
+        "--index-url",
+        data.index_url("yanked"),
+        "--dry-run",
+        "--report",
+        str(report_path),
+    )
+    report = json.loads(report_path.read_text())
+    simple_report = _install_dict(report)["simple"]
+    assert simple_report["requested"] is True
+    assert simple_report["is_direct"] is False
+    assert simple_report["is_yanked"] is False
+    assert simple_report["metadata"]["version"] == "2.0"
+
+
+@pytest.mark.parametrize(
+    "specifiers",
+    [
+        # result should be the same regardless of the method and order in which
+        # extras are specified
+        ("Paste[openid]==1.7.5.1",),
+        ("Paste==1.7.5.1", "Paste[openid]==1.7.5.1"),
+        ("Paste[openid]==1.7.5.1", "Paste==1.7.5.1"),
+    ],
+)
 @pytest.mark.network
-def test_install_report_index(script: PipTestEnvironment, tmp_path: Path) -> None:
+def test_install_report_index(
+    script: PipTestEnvironment, tmp_path: Path, specifiers: Tuple[str, ...]
+) -> None:
     """Test report for sdist obtained from index."""
     report_path = tmp_path / "report.json"
     script.pip(
         "install",
         "--dry-run",
-        "Paste[openid]==1.7.5.1",
+        *specifiers,
         "--report",
         str(report_path),
     )
@@ -93,6 +158,26 @@ def test_install_report_index(script: PipTestEnvironment, tmp_path: Path) -> Non
     assert "requires_dist" in paste_report["metadata"]
 
 
+@pytest.mark.network
+def test_install_report_index_multiple_extras(
+    script: PipTestEnvironment, tmp_path: Path
+) -> None:
+    """Test report for sdist obtained from index, with multiple extras requested."""
+    report_path = tmp_path / "report.json"
+    script.pip(
+        "install",
+        "--dry-run",
+        "Paste[openid]",
+        "Paste[subprocess]",
+        "--report",
+        str(report_path),
+    )
+    report = json.loads(report_path.read_text())
+    install_dict = _install_dict(report)
+    assert "paste" in install_dict
+    assert install_dict["paste"]["requested_extras"] == ["openid", "subprocess"]
+
+
 @pytest.mark.network
 def test_install_report_direct_archive(
     script: PipTestEnvironment, tmp_path: Path, shared_data: TestData
