@@ -35,7 +35,7 @@ def assert_editable(script: PipTestEnvironment, *args: str) -> None:
     ), f"{args!r} not all found in {script.site_packages_path!r}"
 
 
-@pytest.fixture()
+@pytest.fixture
 def make_fake_wheel(script: PipTestEnvironment) -> MakeFakeWheel:
     def _make_fake_wheel(name: str, version: str, wheel_tag: str) -> pathlib.Path:
         wheel_house = script.scratch_path.joinpath("wheelhouse")
@@ -2299,8 +2299,8 @@ def test_new_resolver_dont_backtrack_on_extra_if_base_constrained(
     script.assert_installed(pkg="1.0", dep="1.0")
 
 
-@pytest.mark.parametrize("swap_order", (True, False))
-@pytest.mark.parametrize("two_extras", (True, False))
+@pytest.mark.parametrize("swap_order", [True, False])
+@pytest.mark.parametrize("two_extras", [True, False])
 def test_new_resolver_dont_backtrack_on_extra_if_base_constrained_in_requirement(
     script: PipTestEnvironment, swap_order: bool, two_extras: bool
 ) -> None:
@@ -2337,8 +2337,8 @@ def test_new_resolver_dont_backtrack_on_extra_if_base_constrained_in_requirement
     script.assert_installed(pkg="1.0", dep="1.0")
 
 
-@pytest.mark.parametrize("swap_order", (True, False))
-@pytest.mark.parametrize("two_extras", (True, False))
+@pytest.mark.parametrize("swap_order", [True, False])
+@pytest.mark.parametrize("two_extras", [True, False])
 def test_new_resolver_dont_backtrack_on_conflicting_constraints_on_extras(
     tmpdir: pathlib.Path,
     virtualenv: VirtualEnvironment,
@@ -2518,7 +2518,7 @@ def test_new_resolver_works_when_failing_package_builds_are_disallowed(
     script.assert_installed(pkg2="1.0", pkg1="1.0")
 
 
-@pytest.mark.parametrize("swap_order", (True, False))
+@pytest.mark.parametrize("swap_order", [True, False])
 def test_new_resolver_comes_from_with_extra(
     script: PipTestEnvironment, swap_order: bool
 ) -> None:
