@@ -12,6 +12,7 @@ import pytest
 
 from pip._internal.req.constructors import install_req_from_line
 from pip._internal.utils.misc import rmtree
+
 from tests.lib import (
     PipTestEnvironment,
     TestData,
@@ -637,11 +638,19 @@ def test_uninstall_setuptools_develop_install(
     script.assert_installed(FSPkg="0.1.dev0")
     # Uninstall both develop and install
     uninstall = script.pip("uninstall", "FSPkg", "-y")
-    assert any(p.suffix == ".egg" for p in uninstall.files_deleted), str(uninstall)
     uninstall2 = script.pip("uninstall", "FSPkg", "-y")
-    assert (
+    # Depending on the metadata backend, the egg-link will be uninstalled first
+    # or second, so we use xor in the assertions below.
+    assert (join(script.site_packages, "FSPkg.egg-link") in uninstall.files_deleted) ^ (
         join(script.site_packages, "FSPkg.egg-link") in uninstall2.files_deleted
-    ), str(uninstall2)
+    )
+    assert any(
+        p.name.startswith("FSPkg") and p.suffix == ".egg"
+        for p in uninstall.files_deleted
+    ) ^ any(
+        p.name.startswith("FSPkg") and p.suffix == ".egg"
+        for p in uninstall2.files_deleted
+    )
     script.assert_not_installed("FSPkg")
 
 
@@ -669,7 +678,7 @@ def test_uninstall_editable_and_pip_install(
     script.assert_not_installed("FSPkg")
 
 
-@pytest.fixture()
+@pytest.fixture
 def move_easy_install_pth(script: PipTestEnvironment) -> Iterator[None]:
     """Move easy-install.pth out of the way for testing easy_install."""
     easy_install_pth = join(script.site_packages_path, "easy-install.pth")
